@@ -17,7 +17,7 @@ class TaskManager():
 
     description = 'Methods for loading, running and terminating tasks implementing python\'s threading ' \
                   'library, PyQT\'s QThreading library, asyncio, and multiprocessing'
-    version = '0.0.5'
+    version = '0.0.7'
     tasks = {} #dictionary of loaded tasks
     running_tasks = {} #dictionary of running tasks (i.e. instances of threads)
 
@@ -27,10 +27,17 @@ class TaskManager():
     #load a single task into flab. The task name is given by the filename, without the '.py' at the end
     def load_task(self,task_name):
         load_err = ''
-        cwf = 'Projects.' + os.path.split(os.getcwd())[1]
+        sys.path.append(os.getcwd())
         try:
-            mo = importlib.import_module(cwf+'.Tasks.' + task_name)
+            module_name = 'Projects.' + os.path.split(os.getcwd())[1] + '.Tasks.' + task_name
+            file_path = os.getcwd() + '/Tasks/' + task_name + '.py'
+            spec = importlib.util.spec_from_file_location(module_name, file_path)
+            mo = importlib.util.module_from_spec(spec)
+            sys.modules[module_name] = mo
+            spec.loader.exec_module(mo)
+
             nt = mo.Task(self)
+
             #dictionary entry
             mod = {task_name:mo}
             ntd = {task_name:nt}
